AuthService class

Constructors

AuthService()

Properties

currentUser → User?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isLoggedIn() Future<bool>
login({required String email, required String password}) Future<bool>
logout() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required String email, required String password}) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AuthService
no setter