DB class

Constructors

DB()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add<T extends RealmObject>(T item) → dynamic
delete<T extends RealmObject>(T item) → dynamic
deleteAll<T extends RealmObject>() → dynamic
find<T extends RealmObject>(ObjectId objectId) → dynamic
get<T extends RealmObject>({String query = "", List<Object?> arguments = const []}) → RealmResults<Object?>
init() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot<T extends RealmObject>({String query = "", List<Object?> arguments = const []}) → dynamic
toString() String
A string representation of this object.
inherited
update<T extends RealmObject>(T target, dynamic callback(T current, T item)) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DB
no setter